@@ -1,5 +1,5 @@
 /* *************************************************************************
- *  Copyright 2012 Jakob Gruber <jakob.gruber@gmail.com>                   *
+ *  Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
  *  it under the terms of the GNU General Public License as published by   *
@@ -18,30 +18,33 @@
 
 #include "mainwindow.h"
 
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KStandardGameAction>
+#include <KToggleFullScreenAction>
 #include <QCoreApplication>
 #include <QGraphicsSimpleTextItem>
 #include <QHBoxLayout>
+#include <QMenuBar>
 #include <QPointer>
-#include <iostream>
-#include <kactioncollection.h>
-#include <klocalizedstring.h>
-#include <kmenubar.h>
-#include <kmessagebox.h>
-#include <kstandardgameaction.h>
-#include <kstatusbar.h>
-#include <ktogglefullscreenaction.h>
+#include <QPushButton>
+#include <QStatusBar>
 
-#include "selectboardwindow.h"
-#include "settingswindow.h"
 #include "src/constants.h"
 #include "src/logic/levelloader.h"
+#include "src/logic/picmi.h"
+#include "src/settings.h"
+#include "selectboardwindow.h"
+#include "settingswindow.h"
+#include "scene.h"
 
 MainWindow::MainWindow(QWidget *parent) :
     KXmlGuiWindow(parent),
     m_key_pos("window/position"), m_in_progress(false), m_mode(Random)
 {
-    QCoreApplication::setOrganizationName(ORGANIZATION_NAME);
     QCoreApplication::setApplicationName("picmi");
+    QCoreApplication::setOrganizationDomain("kde.org");
 
     m_timer.setInterval(500);
 
@@ -67,18 +70,18 @@ void MainWindow::setupActions() {
     m_action_solve = KStandardGameAction::solve(this, SLOT(solve()), actionCollection());
 
     /* Prevent the default hint shortcut from overwriting our HJKL vim-like control mapping. */
-    m_action_hint->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_I));
+    actionCollection()->setDefaultShortcut(m_action_hint, QKeySequence(Qt::CTRL + Qt::Key_I));
 
     m_action_save_state = actionCollection()->addAction("save-position");
     m_action_save_state->setText(i18n("Save Position"));
-    m_action_save_state->setIcon(KIcon("list-add"));
-    m_action_save_state->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_S));
+    m_action_save_state->setIcon(QIcon::fromTheme("list-add"));
+    actionCollection()->setDefaultShortcut(m_action_save_state, QKeySequence(Qt::CTRL + Qt::Key_S));
     connect(m_action_save_state, SIGNAL(triggered()), this, SLOT(saveState()));
 
     m_action_load_state = actionCollection()->addAction("load-position");
     m_action_load_state->setText(i18n("Load Position"));
-    m_action_load_state->setIcon(KIcon("view-refresh"));
-    m_action_load_state->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_L));
+    m_action_load_state->setIcon(QIcon::fromTheme("view-refresh"));
+    actionCollection()->setDefaultShortcut(m_action_load_state, QKeySequence(Qt::CTRL + Qt::Key_L));
     connect(m_action_load_state, SIGNAL(triggered()), this, SLOT(loadState()));
 
     m_status_time = new QLabel;
@@ -86,6 +89,18 @@ void MainWindow::setupActions() {
     m_status_position = new QLabel;
     m_status_position->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
 
+    m_new_game = new QPushButton;
+    m_new_game->setText(i18n("New Game"));
+    m_new_game->setVisible(false);
+    connect(m_new_game, SIGNAL(clicked(bool)), this, SLOT(startRandomGame()));
+
+    m_load_game = new QPushButton;
+    m_load_game->setText(i18n("Load New Game"));
+    m_load_game->setVisible(false);
+    connect(m_load_game, SIGNAL(clicked(bool)), this, SLOT(loadBoard()));
+
+    this->statusBar()->addWidget(m_new_game, 0);
+    this->statusBar()->addWidget(m_load_game, 0);
     this->statusBar()->addWidget(m_status_position, 1);
     this->statusBar()->addWidget(m_status_time, 1);
 
@@ -121,13 +136,6 @@ void MainWindow::levelChanged(const KgDifficultyLevel* level) {
 
 void MainWindow::toggleFullscreen(bool full_screen) {
     KToggleFullScreenAction::setFullScreen(this, full_screen);
-    if (full_screen) {
-        menuBar()->hide();
-        statusBar()->hide();
-    } else {
-        menuBar()->show();
-        statusBar()->show();
-    }
 }
 
 void MainWindow::undoStackSizeChanged(int size)
@@ -146,14 +154,14 @@ void MainWindow::closeEvent(QCloseEvent *event) {
 }
 
 void MainWindow::saveWindowState() {
-    QSettings settings;
-    settings.setValue(m_key_pos, pos());
-    settings.sync();
+    QSharedPointer<QSettings> settings = Settings::instance()->qSettings();
+    settings->setValue(m_key_pos, pos());
+    settings->sync();
 }
 
 void MainWindow::restoreWindowState() {
-    QSettings settings;
-    QPoint p = settings.value(m_key_pos, pos()).toPoint();
+    QSharedPointer<QSettings> settings = Settings::instance()->qSettings();
+    QPoint p = settings->value(m_key_pos, pos()).toPoint();
 
     move(p);
 }
@@ -214,7 +222,7 @@ void MainWindow::startPresetGame(QSharedPointer<Level> board) {
 void MainWindow::startGame() {
 
     if (m_scene) {
-        disconnect(&m_timer, SIGNAL(timeout()), this, SLOT(updatePlayedTime()));
+        disconnect(&m_timer, &QTimer::timeout, this, &MainWindow::updatePlayedTime);
     }
 
     m_action_undo->setEnabled(false);
@@ -224,6 +232,9 @@ void MainWindow::startGame() {
     m_action_load_state->setEnabled(false);
     m_action_pause->setEnabled(true);
     m_action_pause->setChecked(false);
+    m_status_position->setVisible(true);
+    m_load_game->setVisible(false);
+    m_new_game->setVisible(false);
     Kg::difficulty()->setGameRunning(true);
 
     m_timer.start();
@@ -235,7 +246,7 @@ void MainWindow::startGame() {
     m_view.setFocus();
     m_view.setPaused(false);
 
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(updatePlayedTime()));
+    connect(&m_timer, &QTimer::timeout, this, &MainWindow::updatePlayedTime);
     connect(m_game.data(), SIGNAL(stateChanged()), this, SLOT(updatePositions()));
     connect(m_game.data(), SIGNAL(gameCompleted()), this, SLOT(gameCompleted()));
     connect(m_game.data(), SIGNAL(gameWon()), this, SLOT(gameWon()));
@@ -267,13 +278,18 @@ QSharedPointer<KScoreDialog> MainWindow::createScoreDialog() {
 void MainWindow::gameWon() {
     KScoreDialog::FieldInfo score = m_game->endGame();
     bool notified = false;
-    if (m_mode == Random && Kg::difficultyLevel() != KgDifficultyLevel::Custom) {
-        QSharedPointer<KScoreDialog> scoreDialog = createScoreDialog();
-        if (scoreDialog->addScore(score, KScoreDialog::LessIsMore | KScoreDialog::AskName) != 0) {
-            scoreDialog->exec();
-            notified = true;
+    m_status_position->setVisible(false);
+    if (m_mode == Random) {
+        m_new_game->setVisible(true);
+        if (Kg::difficultyLevel() != KgDifficultyLevel::Custom) {
+            QSharedPointer<KScoreDialog> scoreDialog = createScoreDialog();
+            if (scoreDialog->addScore(score, KScoreDialog::LessIsMore | KScoreDialog::AskName) != 0) {
+                scoreDialog->exec();
+                notified = true;
+            }
         }
     } else if (m_mode == Preset) {
+        m_load_game->setVisible(true);
         m_current_level->setSolved(m_game->elapsedSecs());
     }
 
